@@ -7,12 +7,10 @@
 import os
 import sys
 import time
-from fast_tracker import config
 
 startup_debug = os.environ.get("FastTracker.Debug", "off").lower() in ("on", "true", "1")
 fast_debug_level = int(os.environ.get("FastTracker.Debug.Level", "0"))
-if config.get_logging_level() == "ERROR":
-    fast_debug_level = 0
+
 
 def log_message(text, *args, level=1):
     if startup_debug:
@@ -23,6 +21,7 @@ def log_message(text, *args, level=1):
             sys.stdout.flush()
 
 
+log_message("fast_debug_level:%d", fast_debug_level)
 log_message("working_directory = %r", os.getcwd())
 
 log_message("sys.prefix = %r", os.path.normpath(sys.prefix))
@@ -64,7 +63,7 @@ except ImportError:
 else:
     log_message("sitecustomize = %r", (file, pathname, description))
 
-     # imp.load_module("sitecustomize", file, pathname, description)
+    # imp.load_module("sitecustomize", file, pathname, description)
 
 expected_python_prefix = os.environ.get("FAST_PYTHON_PREFIX")
 log_message("FAST_PYTHON_PREFIX= %r", os.environ.get("FAST_PYTHON_PREFIX"))
