@@ -5,6 +5,7 @@
     created by FAST-DEV 2021/4/6
 """
 import json
+import os
 import socket
 from fast_tracker import config
 from fast_tracker.fast_tracker import FastTracker
@@ -15,6 +16,7 @@ from fast_tracker.utils import functions
 DEFAULT_UDP_IP = "127.0.0.1"
 DEFAULT_UDP_PORT = 5140
 
+
 class UdpTraceSegmentReportService(TraceSegmentReportService):
     def __init__(self):
         self.udp_ip = DEFAULT_UDP_IP
@@ -65,13 +67,13 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
             functions.log("udp socket object success")
             for segment in generator:
                 for span in segment.spans:
-                    functions.log("udp socket object will get data", level=4)
+                    # functions.log("udp socket object will get data", level=4)
                     data = self._get_data(segment, span)
                     functions.log("udp socket ip: %s, port: %d", self.udp_ip, self.udp_port)
-                    functions.log("udp socket object get data", level=4)
+                    # functions.log("udp socket object get data", level=4)
                     res = udp_sock.sendto(data, (self.udp_ip, self.udp_port))
-                    # res = udp_sock.sendto(data, ("fluent-bit", 5140))
-                    functions.log("sended udp socket ip: %s, port: %d", self.udp_ip, self.udp_port)
+                    # res = udp_sock.sendto(data, ("fast-collector", self.udp_port))
+                    # functions.log("sended udp socket ip: %s, port: %d", self.udp_ip, self.udp_port)
                     functions.log("sended message: %r, result is: %r", data, res)
                 # segment上报完清除用户自定义字段值，避免污染之后的上报
                 config.custom_env_code = ""
@@ -80,6 +82,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         except BaseException as e:
             functions.log("udp report error: %r", e)
 
+
     def _get_data(self, segment, span):
         """
         udp 数据包组装
@@ -109,11 +112,11 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         report_struct.is_error = span.error_occurred
         report_struct.tags = self.convert_tags(span.tags)
         report_struct.logs = self.convert_logs(span.logs)
-        report_struct.service_instance = ""
-        report_struct.service_version = ""
-        # report_struct.tracker_version = config.tracker_version
+        report_struct.service_instance = config.service_name + "|" + str(os.getpid())+"|"+socket.gethostname()
+        report_struct.service_version = config.get_service_version()
+        report_struct.tracker_version = config.tracker_version
         item = ReportStruct.convert(report_struct)
-        functions.log("report_struct: %r", item, level=2)
+        #functions.log("report_struct: %r", item, level=2)
         data = json.dumps(item).encode("utf-8")
         return data
 
@@ -144,7 +147,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
             for item in log.items:
                 if type(item.val) == str:
                     alpha = {
-                        "Timestamp": str(log.timestamp * 1000),
+                        "Timestamp": int(log.timestamp * 1000),
                         "Data": {
                             "event": item.key,
                             "message": item.val,
@@ -159,7 +162,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
                     if item.val.get("err_trace"):
                         temp["stack"] = item.val.get("err_trace")
                     alpha = {
-                        "Timestamp": str(log.timestamp * 1000),
+                        "Timestamp": int(log.timestamp * 1000),
                         "Data": temp,
                     }
                 data.append(alpha)
